@@ -1,8 +1,9 @@
+//! Provides the server functionality.
+
 #![allow(clippy::module_inception)]
 
 pub mod cache;
 pub mod logger;
-pub mod pipe;
 pub mod proxy;
 pub mod rand;
 pub mod server;
